package org.jboss.embedded.http;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.InetSocketAddress;
import java.net.URI;
import java.util.concurrent.Executors;

import com.sun.net.httpserver.HttpExchange;
import com.sun.net.httpserver.HttpHandler;
import com.sun.net.httpserver.HttpServer;


public class ResourceServer implements HttpHandler {

    @Override
    public void handle(HttpExchange http) throws IOException {
        URI request = http.getRequestURI();
        if (! http.getRequestMethod().equals("GET")) {
            http.sendResponseHeaders(405, -1);
            http.getResponseBody().close();
            return;
        }

        String page = request.getPath().substring(1);
        if (page.length() < 1) {
            http.getResponseHeaders().set("Location", "/JSON.html");
            http.sendResponseHeaders(302, -1);
            http.getResponseBody().close();
            return;
        }

        InputStream stream = getClass().getClassLoader().getResourceAsStream(request.getPath().substring(1));
        if (stream == null) {
            http.sendResponseHeaders(404, -1);
            http.getResponseBody().close();
            return;
        }


        http.sendResponseHeaders(200, 0);
        byte[] buffer = new byte[256];
        OutputStream out = http.getResponseBody();

        for(;;) {
            int i = stream.read(buffer);
            if (i < 1)
                break;

            out.write(buffer, 0, i);
        }
        out.flush();
        out.close();
    }

    public static void main(String[] args) throws IOException {
        HttpServer server = HttpServer.create(new InetSocketAddress(8000), 100);
        server.createContext("/", new ResourceServer());
        server.setExecutor(Executors.newFixedThreadPool(10));
        server.start();
        System.out.println("Web Server Started: http://localhost:8000/");
    }

}
